@@ -638,18 +638,6 @@ gupnp_didl_lite_resource_class_init (GUPnPDIDLLiteResourceClass *klass)
                                    G_PARAM_STATIC_BLURB));
 }
 
-/**
- * gupnp_didl_lite_resource_new
- *
- * Return value: A new #GUPnPDIDLLiteResource object. Unref after usage.
- **/
-GUPnPDIDLLiteResource *
-gupnp_didl_lite_resource_new (void)
-{
-        return g_object_new (GUPNP_TYPE_DIDL_LITE_RESOURCE,
-                             NULL);
-}
-
 /**
  * gupnp_didl_lite_resource_new_from_xml
  * @xml_node: The pointer to 'res' node in XML document
@@ -702,6 +690,9 @@ gupnp_didl_lite_resource_get_uri (GUPnPDIDLLiteResource *resource)
 {
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource), NULL);
 
+        if (G_UNLIKELY (resource->priv->xml_node->children == NULL))
+                return NULL;
+
         return (const char *) resource->priv->xml_node->children->content;
 }
 
@@ -1016,7 +1007,7 @@ gupnp_didl_lite_resource_set_import_uri (GUPnPDIDLLiteResource *resource,
 /**
  * gupnp_didl_lite_resource_set_protocol_info
  * @resource: A #GUPnPDIDLLiteResource
- * @protocol: The protocol string
+ * @info: The protocol string
  *
  * Set the protocol info associated with the @resource. If the
  * #GUPnPProtocolInfo:dlna-profile of @info is not set, an attempt will be made 
@@ -1126,7 +1117,7 @@ gupnp_didl_lite_resource_set_duration (GUPnPDIDLLiteResource *resource,
         else {
                 char *str;
 
-                str = g_strdup_printf ("%ld:%.2ld:%.2ld",
+                str = g_strdup_printf ("%ld:%.2ld:%.2ld.00",
                                        duration / (60 * 60),
                                        (duration / 60) % 60,
                                        duration % 60);
@@ -1365,7 +1356,7 @@ gupnp_didl_lite_resource_set_height (GUPnPDIDLLiteResource *resource,
 /**
  * gupnp_didl_lite_resource_set_color_depth
  * @resource: A #GUPnPDIDLLiteResource
- * @height: The color-depth
+ * @color_depth: The color-depth
  *
  * Set the color-depth of this image/video resource. Passing a negative number
  * will unset this property.
